OpenCensus Utils - A collection of tools for use with OpenCensus Python
=======================================================================

A colection of utilities for  https://github.com/census-instrumentation

Python
------
- trace
  - propagator
    - jaeger
  - asyncio_context
  - tracers
    - asyncio_context_tracer
  - ext
    - sanic
    - aiohttp
    - aioredis


Installation & basic usage
--------------------------

For python

1. Install the qubit-opencensus package using `pip`_ or `pipenv`_:

    ::

        pip install qubit-opencensus


